Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(355)

Unified Diff: public/platform/WebScheduler.h

Issue 1348853002: scheduler: Rename WebPageScheduler to WebFrameHostScheduler (Closed) Base URL: svn://svn.chromium.org/blink/trunk
Patch Set: Created 5 years, 3 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « public/platform/WebPageScheduler.h ('k') | no next file » | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: public/platform/WebScheduler.h
diff --git a/public/platform/WebScheduler.h b/public/platform/WebScheduler.h
index dd0105f813b4eac613438a7fe0e00f440197ed86..122918693a863641b39726789d7690050ba2440a 100644
--- a/public/platform/WebScheduler.h
+++ b/public/platform/WebScheduler.h
@@ -11,7 +11,7 @@
namespace blink {
-class WebPageScheduler;
+class WebFrameHostScheduler;
class WebTraceLocation;
// This class is used to submit tasks and pass other information from Blink to
@@ -73,8 +73,8 @@ public:
// Returns a WebTaskRunner for timer tasks. Can be called from any thread.
virtual WebTaskRunner* timerTaskRunner() { return nullptr; }
- // Creates a new WebPageScheduler. Must be called from the associated WebThread.
- virtual WebPageScheduler* createPageScheduler() { return nullptr; }
+ // Creates a new WebFrameHostScheduler. Must be called from the associated WebThread.
+ virtual WebFrameHostScheduler* createFrameHostScheduler() { return nullptr; }
// Suspends the timer queue and increments the timer queue suspension count.
// May only be called from the main thread.
« no previous file with comments | « public/platform/WebPageScheduler.h ('k') | no next file » | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698